@@ -1,5 +1,5 @@
 load("Storms.NMC.Rdata")
 Storms.NMC <- results
 class(Storms.NMC) <- "CCI.object"
-rm(results)
+rm(results); gc(reset=TRUE)
 
